import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * This resource will manage the lifecycle of items in a DynamoDB table
 *
 * @schema CfnItemProps
 */
export interface CfnItemProps {
    /**
     * @schema CfnItemProps#Item
     */
    readonly item?: any;
    /**
     * @schema CfnItemProps#Keys
     */
    readonly keys: Key[];
    /**
     * The table to put the item into
     *
     * @schema CfnItemProps#TableName
     */
    readonly tableName: string;
}
/**
 * Converts an object of type 'CfnItemProps' to JSON representation.
 */
export declare function toJson_CfnItemProps(obj: CfnItemProps | undefined): Record<string, any> | undefined;
/**
 * @schema Key
 */
export interface Key {
    /**
     * @schema Key#AttributeName
     */
    readonly attributeName: string;
    /**
     * @schema Key#AttributeType
     */
    readonly attributeType: string;
    /**
     * @schema Key#AttributeValue
     */
    readonly attributeValue: string;
}
/**
 * Converts an object of type 'Key' to JSON representation.
 */
export declare function toJson_Key(obj: Key | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `AwsCommunity::DynamoDB::Item`
 *
 * @cloudformationResource AwsCommunity::DynamoDB::Item
 * @stability external
 * @link https://github.com/aws-cloudformation/community-registry-extensions.git
 */
export declare class CfnItem extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "AwsCommunity::DynamoDB::Item";
    /**
     * Resource props.
     */
    readonly props: CfnItemProps;
    /**
     * Attribute `AwsCommunity::DynamoDB::Item.CompositeKey`
     * @link https://github.com/aws-cloudformation/community-registry-extensions.git
     */
    readonly attrCompositeKey: string;
    /**
     * Create a new `AwsCommunity::DynamoDB::Item`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnItemProps);
}
